@@ -532,21 +532,19 @@ func TestDockerCommandMissingServiceImage(t *testing.T) {
 	assert.Contains(t, err.Error(), contains)
 }
 
-// TestDockerCommandPullingImageRequestTimeout tests if the request timeout cancelation
-// is categorized as a script failure. It also helps to monitor the eventual error message change in
-// future docker library versions
-func TestDockerCommandPullingImageRequestTimeout(t *testing.T) {
+// TestDockerCommandPullingImageNoHost tests if the DNS resolution failure for the registry host
+// is categorized as a script failure.
+func TestDockerCommandPullingImageNoHost(t *testing.T) {
 	helpers.SkipIntegrationTests(t, "docker", "info")
 
 	build := getBuildForOS(t, common.GetSuccessfulBuild)
-	build.Runner.RunnerSettings.Docker.Image = "docker.repo.bogus.com.au/docker:18.09.7-dind"
+	build.Runner.RunnerSettings.Docker.Image = "docker.repo.example.com/docker:18.09.7-dind"
 
 	var buildError *common.BuildError
 	err := build.Run(&common.Config{}, &common.Trace{Writer: os.Stdout})
 	require.ErrorAs(t, err, &buildError)
 
 	assert.Equal(t, common.ScriptFailure, buildError.FailureReason, "expected script failure error")
-	assert.Contains(t, err.Error(), "request canceled while waiting for connection")
 }
 
 func TestDockerCommandBuildCancel(t *testing.T) {
