@@ -18,6 +18,10 @@ func TestScrubSecrets(t *testing.T) {
 			input:  "Get http://localhost/?id=123&X-Amz-Signature=abcd1234&private_token=abcd1234",
 			output: "Get http://localhost/?id=123&X-Amz-Signature=[FILTERED]&private_token=[FILTERED]",
 		},
+		{
+			input:  "Get http://localhost/?id=123&X-Amz-Security-Token=abcd1234&private_token=abcd1234",
+			output: "Get http://localhost/?id=123&X-Amz-Security-Token=[FILTERED]&private_token=[FILTERED]",
+		},
 		{
 			input: "Get http://localhost/?id=123&" +
 				"X-Amz-Credential=ABCDEF123456%2F20180920%2Fus-east-1%2Fs3%2Faws4_request",
